Index: webrtc/api/objc/RTCVideoRendererAdapter+Private.h |
diff --git a/webrtc/api/objc/RTCVideoRendererAdapter+Private.h b/webrtc/api/objc/RTCVideoRendererAdapter+Private.h |
index c181b9b41c8fb1511e0059d29be808e2ec70e12e..f0e0c6c0adda956fdae989054ffd58891b959a8d 100644 |
--- a/webrtc/api/objc/RTCVideoRendererAdapter+Private.h |
+++ b/webrtc/api/objc/RTCVideoRendererAdapter+Private.h |
@@ -26,12 +26,12 @@ NS_ASSUME_NONNULL_BEGIN |
@property(nonatomic, readonly) id<RTCVideoRenderer> videoRenderer; |
/** |
* The native VideoRendererInterface surface exposed by this adapter. Calls made |
* to this interface will be adapted and passed to the RTCVideoRenderer supplied |
* during construction. This pointer is unsafe and owned by this class. |
*/ |
@property(nonatomic, readonly) |
- webrtc::VideoRendererInterface *nativeVideoRenderer; |
+ rtc::VideoSinkInterface<cricket::VideoFrame> *nativeVideoRenderer; |
/** Initialize an RTCVideoRendererAdapter with an RTCVideoRenderer. */ |
- (instancetype)initWithNativeRenderer:(id<RTCVideoRenderer>)videoRenderer |
@@ -26,12 +26,12 @@ NS_ASSUME_NONNULL_BEGIN |
/** |
- * The native VideoRendererInterface surface exposed by this adapter. Calls made |
+ * The native VideoSinkInterface surface exposed by this adapter. Calls made |
* to this interface will be adapted and passed to the RTCVideoRenderer supplied |
* during construction. This pointer is unsafe and owned by this class. |